@@ -1,22 +1,20 @@
-# ##########################   Qt_Colored-logger   ########################### #
-# ---------------------------------------------------------------------------- #
-#                                                                              #
-# Copyright © 2023 Kalynovsky Valentin. All rights reserved.                   #
-#                                                                              #
-# Licensed under the Apache License, Version 2.0 (the "License");              #
-# you may not use this file except in compliance with the License.             #
-# You may obtain a copy of the License at                                      #
-#                                                                              #
-#     http://www.apache.org/licenses/LICENSE-2.0                               #
-#                                                                              #
-# Unless required by applicable law or agreed to in writing, software          #
-# distributed under the License is distributed on an "AS IS" BASIS,            #
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.     #
-# See the License for the specific language governing permissions and          #
-# limitations under the License.                                               #
-#                                                                              #
-# ---------------------------------------------------------------------------- #
-# ############################################################################ #
+"""
+Module with implementation of ANSI escape codes.
+\n
+Copyright © 2023 Kalynovsky Valentin. All rights reserved.
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
 
 AnsiFormat = {
 	# Source: https://en.wikipedia.org/wiki/ANSI_escape_code
@@ -153,7 +151,7 @@ AnsiFormat = {
 	},
 }
 
-def _RecursiveGetAnsiFormat(ansi_address: str, ansi: dict, test: bool = False) -> str:
+def _RecursiveGetAnsiFormat(ansi_address: str, ansi: dict) -> str:
 	"""
 	Recursively extracts a string with an ANSI escape code from a heavily nested dictionary.
 
@@ -162,8 +160,7 @@ def _RecursiveGetAnsiFormat(ansi_address: str, ansi: dict, test: bool = False) -
 	:return: value - ANSI escape code
 	"""
 	split_address = ansi_address.split("/")
-	if test:
-		print(split_address)
+	# print(split_address)
 	if type(ansi[split_address[0]]) == dict:
 		return _RecursiveGetAnsiFormat("/".join(split_address[1:]), ansi[split_address[0]])
 	else:
@@ -189,12 +186,3 @@ def GetAnsiFormat(ansi_address: str) -> str:
 	:return: ANSI escape code
 	"""
 	return _RecursiveGetAnsiFormat(ansi_address, AnsiFormat)
-
-if __name__ == "__main__":
-	print(f"{GetAnsiFormat('italic/fraktur')}Test string")
-	print(f"{GetAnsiFormat('blink/slow')}Test string")
-	print(f"{GetAnsiFormat('invert/off')}Test string")
-	print(f"{GetAnsiFormat('font/3rd alternative')}Test string")
-	print(f"{GetAnsiFormat('color/foreground/green')}Test string")
-	print(f"{GetAnsiFormat('color/set/background/255;255;255')}Test string")
-	print(f"{GetAnsiFormat('reset/on')}Test string")
